import React, { useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { clearNotifications } from '../store/notificationCenter/notificationCenter.slice';
import RequestDetailSlideOver from '../pages/Permissions/components/RequestDetailSlideOver';
import { approvePermissionThunk, rejectPermissionThunk } from '../store/permissions/permissions.thunks';
import { showNotification } from '../store/notification.slice';

export default function NotificationCenter({ show, onClose }) {
    const [showAll, setShowAll] = useState(false);
    const dispatch = useDispatch();
    const { notifications } = useSelector((state) => state.notificationCenter);
    const [selectedRequest, setSelectedRequest] = useState(null);
    const [showSlideOver, setShowSlideOver] = useState(false);
    const [showResponseInput, setShowResponseInput] = useState(false);
    const [currentRequestId, setCurrentRequestId] = useState(null);
    const [isApproving, setIsApproving] = useState(false);
    const [responseMessage, setResponseMessage] = useState('');

    const displayedNotifications = showAll ? notifications : notifications.slice(0, 2);

    const handleClearAll = () => {
        dispatch(clearNotifications());
    };

    const handleViewDetail = (notification) => {
        if (notification.type === 'permission') {
            setSelectedRequest(notification);
            setShowSlideOver(true);
        }
    };

    const handleCloseSlideOver = () => {
        setShowSlideOver(false);
        setTimeout(() => {
            setSelectedRequest(null);
        }, 300);
    };

    const handleOpenResponseInput = (requestId, approving) => {
        setCurrentRequestId(requestId);
        setIsApproving(approving);
        setShowResponseInput(true);
    };

    const handleCloseResponseInput = () => {
        setShowResponseInput(false);
        setCurrentRequestId(null);
        setResponseMessage('');
    };

    const handleProcessRequest = () => {
        if (!currentRequestId) return;

        const params = {
            id: currentRequestId,
            responseMessage,
        };

        if (isApproving) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    if (!show) return null;

    return (
        <>
            <div
                className='notification-center card shadow-lg'
                style={{
                    position: 'fixed',
                    top: '60px',
                    right: '20px',
                    width: '400px',
                    zIndex: 1050,
                    backgroundColor: 'white',
                    maxHeight: '80vh',
                    display: 'flex',
                    flexDirection: 'column',
                }}
            >
                <div className='card-header bg-white border-0 d-flex justify-content-between align-items-center py-3'>
                    <h6 className='mb-0'>通知中心</h6>
                    <div className='d-flex gap-3 align-items-center'>
                        <button
                            className='btn btn-link text-decoration-none p-0 text-dark'
                            onClick={handleClearAll}
                            disabled={notifications.length === 0}
                        >
                            清除所有通知
                        </button>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                </div>
                <div className='card-body p-0' style={{ overflowY: 'auto' }}>
                    {displayedNotifications.map((notification) => (
                        <div key={notification.id} className='notification-item p-3 border-bottom hover-bg-light'>
                            <div className='d-flex gap-3'>
                                <div className='notification-icon'>
                                    <i className={`bi ${notification.icon} text-dark fs-5`}></i>
                                </div>
                                <div className='flex-grow-1'>
                                    <div className='d-flex justify-content-between align-items-start'>
                                        <h6 className='mb-1'>{notification.title}</h6>
                                        <small className='text-muted'>{notification.time}</small>
                                    </div>
                                    <p className='mb-1 text-secondary'>{notification.content}</p>
                                    <div className='d-flex gap-2'>
                                        {notification.hasDetail && (
                                            <button
                                                className='btn btn-sm btn-dark'
                                                onClick={() => handleViewDetail(notification)}
                                            >
                                                查看详情
                                            </button>
                                        )}
                                    </div>
                                </div>
                            </div>
                        </div>
                    ))}
                </div>
                <div className='card-footer bg-white border-0 text-center p-3 mt-auto'>
                    <button
                        className='btn btn-link text-decoration-none text-dark'
                        onClick={() => setShowAll(!showAll)}
                    >
                        {showAll ? '收起' : '查看全部通知'}
                    </button>
                </div>
            </div>

            {/* 使用滑动面板组件 */}
            <RequestDetailSlideOver
                show={showSlideOver}
                onClose={handleCloseSlideOver}
                request={selectedRequest}
                onApprove={(id) => handleOpenResponseInput(id, true)}
                onReject={(id) => handleOpenResponseInput(id, false)}
                processingId={currentRequestId}
                approveRejectStatus={showResponseInput ? 'loading' : 'idle'}
                isApproving={isApproving}
            />

            {/* 回复输入弹窗 */}
            {showResponseInput && (
                <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
                    <div className='modal-dialog'>
                        <div className='modal-content'>
                            <div className='modal-header'>
                                <h5 className='modal-title'>{isApproving ? '批准' : '拒绝'}申请</h5>
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={handleCloseResponseInput}
                                    disabled={showResponseInput}
                                ></button>
                            </div>
                            <div className='modal-body'>
                                <div className='mb-3'>
                                    <label htmlFor='responseMessage' className='form-label'>
                                        审批意见
                                    </label>
                                    <textarea
                                        className='form-control'
                                        id='responseMessage'
                                        rows='3'
                                        value={responseMessage}
                                        onChange={(e) => setResponseMessage(e.target.value)}
                                        placeholder={isApproving ? '请输入批准意见（可选）' : '请输入拒绝理由（可选）'}
                                    ></textarea>
                                </div>
                            </div>
                            <div className='modal-footer'>
                                <button
                                    type='button'
                                    className='btn btn-secondary'
                                    onClick={handleCloseResponseInput}
                                    disabled={showResponseInput}
                                >
                                    取消
                                </button>
                                <button
                                    type='button'
                                    className={`btn ${isApproving ? 'btn-success' : 'btn-danger'}`}
                                    onClick={handleProcessRequest}
                                    disabled={showResponseInput}
                                >
                                    {showResponseInput ? (
                                        <>
                                            <span
                                                className='spinner-border spinner-border-sm me-1'
                                                role='status'
                                                aria-hidden='true'
                                            ></span>
                                            处理中...
                                        </>
                                    ) : isApproving ? (
                                        '确认批准'
                                    ) : (
                                        '确认拒绝'
                                    )}
                                </button>
                            </div>
                        </div>
                    </div>
                    <div className='modal-backdrop fade show'></div>
                </div>
            )}
        </>
    );
}
