import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchUserPermissions, updateUserPermissions } from '../../../store/permissions/permissions.thunks';
import UserPermissionDetails from './UserPermissionDetails';
import './UserPermissions.css';
import SvgIcon from '../../../components/SvgIcon';

// 每页显示选项
const PAGE_SIZE_OPTIONS = [5, 10, 15, 20];

export default function UserPermissions() {
    const dispatch = useDispatch();
    const [selectedUser, setSelectedUser] = useState(null);
    const [showDetailsModal, setShowDetailsModal] = useState(false);
    const [searchTerm, setSearchTerm] = useState('');

    // 分页状态
    const [currentPage, setCurrentPage] = useState(1);
    const [pageSize, setPageSize] = useState(5);
    const [totalPages, setTotalPages] = useState(1);

    // 从 Redux store 获取用户列表和状态
    const { items: users, status: loading, error } = useSelector((state) => state.permissions.users);

    // 获取用户列表
    useEffect(() => {
        dispatch(fetchUserPermissions());
    }, [dispatch]);

    // 当用户列表或搜索词变化时，更新总页数
    useEffect(() => {
        const filteredUsers = getFilteredUsers();
        setTotalPages(Math.ceil(filteredUsers.length / pageSize));
        // 如果当前页超出了新的总页数，则重置为第一页
        if (currentPage > Math.ceil(filteredUsers.length / pageSize)) {
            setCurrentPage(1);
        }
    }, [users, searchTerm, pageSize]);

    // 打开用户权限详情弹窗
    const handleOpenDetailsModal = (user) => {
        setSelectedUser(user);
        setShowDetailsModal(true);
    };

    // 关闭用户权限详情弹窗
    const handleCloseDetailsModal = () => {
        setShowDetailsModal(false);
        setSelectedUser(null);
    };

    // 保存用户权限更改
    const handleSavePermissions = async (userId, updatedPermissions) => {
        try {
            await dispatch(updateUserPermissions({ userId, permissions: updatedPermissions })).unwrap();
            handleCloseDetailsModal();
        } catch (error) {
            console.error('更新权限失败:', error);
        }
    };

    // 处理搜索输入变化
    const handleSearchChange = (e) => {
        setSearchTerm(e.target.value);
        setCurrentPage(1); // 重置为第一页
    };

    // 处理页码变化
    const handlePageChange = (page) => {
        setCurrentPage(page);
    };

    // 处理每页显示数量变化
    const handlePageSizeChange = (e) => {
        const newPageSize = parseInt(e.target.value);
        setPageSize(newPageSize);
        setCurrentPage(1); // 重置为第一页
    };

    // 获取过滤后的用户列表
    const getFilteredUsers = () => {
        if (!searchTerm.trim()) return users;
        return users.filter(
            (user) =>
                user.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.username.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.department.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.position.toLowerCase().includes(searchTerm.toLowerCase())
        );
    };

    // 获取当前页的数据
    const getCurrentPageData = () => {
        const filteredUsers = getFilteredUsers();
        const startIndex = (currentPage - 1) * pageSize;
        const endIndex = startIndex + pageSize;
        return filteredUsers.slice(startIndex, endIndex);
    };

    // 渲染分页控件
    const renderPagination = () => {
        if (totalPages <= 1) return null;

        return (
            <div className='d-flex justify-content-center align-items-center mt-4'>
                <nav aria-label='用户权限分页'>
                    <ul className='pagination dark-pagination'>
                        <li className={`page-item ${currentPage === 1 ? 'disabled' : ''}`}>
                            <button
                                className='page-link'
                                onClick={() => handlePageChange(currentPage - 1)}
                                disabled={currentPage === 1}
                            >
                                上一页
                            </button>
                        </li>
                        <li className='page-item active'>
                            <span className='page-link'>
                                {currentPage} / {totalPages}
                            </span>
                        </li>
                        <li className={`page-item ${currentPage === totalPages ? 'disabled' : ''}`}>
                            <button
                                className='page-link'
                                onClick={() => handlePageChange(currentPage + 1)}
                                disabled={currentPage === totalPages}
                            >
                                下一页
                            </button>
                        </li>
                    </ul>
                </nav>

                <div className='ms-3'>
                    <select
                        className='form-select form-select-sm'
                        value={pageSize}
                        onChange={handlePageSizeChange}
                        aria-label='每页显示数量'
                    >
                        {PAGE_SIZE_OPTIONS.map((size) => (
                            <option key={size} value={size}>
                                {size}条/页
                            </option>
                        ))}
                    </select>
                </div>
            </div>
        );
    };

    // 渲染加载状态
    if (loading === 'loading' && users.length === 0) {
        return (
            <div className='text-center py-5'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
                <p className='mt-3'>加载用户列表...</p>
            </div>
        );
    }

    // 渲染错误状态
    if (error && users.length === 0) {
        return (
            <div className='alert alert-danger' role='alert'>
                {error}
            </div>
        );
    }

    // 渲染空状态
    if (users.length === 0) {
        return (
            <div className='alert alert-info' role='alert'>
                暂无用户数据
            </div>
        );
    }

    // 获取当前页的数据
    const currentPageData = getCurrentPageData();

    // 获取过滤后的总用户数
    const filteredUsersCount = getFilteredUsers().length;

    // 渲染用户列表
    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>用户权限管理</h5>
                <div className='input-group' style={{ maxWidth: '250px' }}>
                    <input
                        type='text'
                        className='form-control'
                        placeholder='搜索用户...'
                        value={searchTerm}
                        onChange={handleSearchChange}
                    />
                    <span className='input-group-text'>
                        <SvgIcon className='magnifying-glass' />
                    </span>
                </div>
            </div>

            {filteredUsersCount > 0 ? (
                <>
                    <div className='card'>
                        <div className='table-responsive'>
                            <table className='table table-hover mb-0'>
                                <thead className='table-light'>
                                    <tr>
                                        <th scope='col'>用户</th>
                                        <th scope='col'>部门</th>
                                        <th scope='col'>职位</th>
                                        <th scope='col'>数据集权限</th>
                                        <th scope='col' className='text-end'>
                                            操作
                                        </th>
                                    </tr>
                                </thead>
                                <tbody>
                                    {currentPageData.map((user) => (
                                        <tr key={user.id}>
                                            <td>
                                                <div className='d-flex align-items-center'>
                                                    <div
                                                        className='bg-dark rounded-circle text-white d-flex align-items-center justify-content-center me-2'
                                                        style={{ width: '36px', height: '36px' }}
                                                    >
                                                        {user.name.charAt(0)}
                                                    </div>
                                                    <div>
                                                        <div className='fw-medium'>{user.name}</div>
                                                        <div className='text-muted small'>{user.username}</div>
                                                    </div>
                                                </div>
                                            </td>
                                            <td className='align-middle'>{user.department}</td>
                                            <td className='align-middle'>{user.position}</td>
                                            <td className='align-middle'>
                                                {user.permissions_count && (
                                                    <div className='d-flex flex-wrap gap-1'>
                                                        {user.permissions_count.read > 0 && (
                                                            <span className='badge bg-success-subtle text-success d-flex align-items-center gap-1'>
                                                                完全访问: {user.permissions_count.read}
                                                            </span>
                                                        )}
                                                        {user.permissions_count.edit > 0 && (
                                                            <span className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'>
                                                                只读访问: {user.permissions_count.edit}
                                                            </span>
                                                        )}
                                                        {user.permissions_count.admin > 0 && (
                                                            <span className='badge bg-dark-subtle d-flex align-items-center gap-1'>
                                                                无访问权限: {user.permissions_count.admin}
                                                            </span>
                                                        )}
                                                    </div>
                                                )}
                                            </td>
                                            <td className='text-end align-middle'>
                                                <button
                                                    className='btn btn-outline-dark btn-sm'
                                                    onClick={() => handleOpenDetailsModal(user)}
                                                >
                                                    修改权限
                                                </button>
                                            </td>
                                        </tr>
                                    ))}
                                </tbody>
                            </table>
                        </div>
                    </div>

                    {/* 分页控件 */}
                    {renderPagination()}
                </>
            ) : (
                <div className='alert alert-info' role='alert'>
                    没有找到匹配的用户
                </div>
            )}

            {/* 用户权限详情弹窗 */}
            {showDetailsModal && selectedUser && (
                <UserPermissionDetails
                    user={selectedUser}
                    onClose={handleCloseDetailsModal}
                    onSave={handleSavePermissions}
                />
            )}
        </>
    );
}
